#ifndef NT2_INCLUDE_FUNCTIONS_GE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_GE_HPP_INCLUDED

#include <nt2/operator/include/functions/ge.hpp>

#endif
